@@ -93,7 +93,7 @@ class DepositIntegration:
         confirmed, ``form_for_transaction()`` should return the next form.
 
         :param transaction: the ``Transaction`` database object
-        :param post_data: A `django request.POST`_ object
+        :param post_data: the data sent in the POST request as a dictionary
         :param amount: a ``Decimal`` object the wallet may pass in the GET request.
             Use it to pre-populate your TransactionForm along with any SEP-9_
             parameters.
@@ -126,6 +126,10 @@ class DepositIntegration:
 
             The template used for deposit flows
 
+        ``Template.WITHDRAW``
+
+            The template used for withdraw flows
+
         ``Template.MORE_INFO``
 
             The template used to show transaction details
@@ -232,11 +236,18 @@ class DepositIntegration:
         """
         pass
 
-    def save_sep9_fields(self, stellar_account: str, fields: Dict, language_code: str):
+    def save_sep9_fields(
+        self,
+        stellar_account: str,
+        fields: Dict,
+        language_code: str,
+        account_memo: Optional[str] = None,
+        account_memo_type: Optional[str] = None,
+    ):
         """
-        Save the `fields` passed for `stellar_account` to pre-populate the forms returned
-        from ``form_for_transaction()``. Note that this function is called before
-        the transaction is created.
+        Save the `fields` passed for the user identified by `stellar_account` to pre-populate
+        the forms returned from ``form_for_transaction()``. Note that this function is called
+        before the transaction is created.
 
         For example, you could save the user's contact information with the model used
         for KYC information.
@@ -379,13 +390,12 @@ class WithdrawalIntegration:
         amount: Optional[Decimal] = None,
     ) -> Optional[forms.Form]:
         """
-        .. _django request.POST: https://docs.djangoproject.com/en/3.0/ref/request-response/#django.http.HttpRequest.POST
         .. _SEP-9: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0009.md
 
         Same as ``DepositIntegration.form_for_transaction``
 
         :param transaction: the ``Transaction`` database object
-        :param post_data: A `django request.POST`_ object
+        :param post_data: the data included in the POST request body as a dictionary
         :param amount: a ``Decimal`` object the wallet may pass in the GET request.
             Use it to pre-populate your TransactionForm along with any SEP-9_
             parameters.
@@ -404,7 +414,7 @@ class WithdrawalIntegration:
         template: Template,
         form: Optional[forms.Form] = None,
         transaction: Optional[Transaction] = None,
-    ):
+    ) -> Optional[Dict]:
         """
         Same as ``DepositIntegration.content_for_template``, except the ``Template``
         values passed will be one of:
@@ -450,7 +460,14 @@ class WithdrawalIntegration:
         """
         pass
 
-    def save_sep9_fields(self, stellar_account: str, fields: Dict, language_code: str):
+    def save_sep9_fields(
+        self,
+        stellar_account: str,
+        fields: Dict,
+        language_code: str,
+        account_memo: Optional[str] = None,
+        account_memo_type: Optional[str] = None,
+    ):
         """
         Same as ``DepositIntegration.save_sep9_fields``
         """
