@@ -65,7 +65,7 @@ class Command(BaseCommand):
             ]
         )
 
-    async def _for_account(self, account: str):  # pragma: no cover
+    async def _for_account(self, account: str):
         """
         Stream transactions for the server Stellar address.
         """
@@ -89,10 +89,13 @@ class Command(BaseCommand):
                 .first()
             )
 
-            cursor = "now"
+            cursor = "0"
             if last_completed_transaction:
                 cursor = last_completed_transaction.paging_token
 
+            logger.info(
+                f"starting transaction stream for {account} with cursor {cursor}"
+            )
             endpoint = server.transactions().for_account(account).cursor(cursor)
             async for response in endpoint.stream():
                 self.process_response(response, account)
