@@ -1,5 +1,6 @@
 from django.urls import path
-from django.conf import settings
+
+from polaris import settings
 from polaris.sep6 import info, deposit, withdraw, fee, transaction
 
 urlpatterns = [
@@ -9,5 +10,8 @@ urlpatterns = [
     path("fee", fee.fee),
     path("transaction", transaction.transaction),
     path("transactions", transaction.transactions),
-    path("transaction/more_info", transaction.more_info, name="more_info_sep6"),
 ]
+if settings.SEP6_USE_MORE_INFO_URL:
+    urlpatterns.append(
+        path("transaction/more_info", transaction.more_info, name="more_info_sep6"),
+    )
